//---------------------------------------------------------------------------
// TestMortality
//---------------------------------------------------------------------------
#if !defined(TestCompetitionMortality_H)
  #define TestCompetitionMortality_H

  #include <cppunit/TestFixture.h>
  #include <cppunit/TestCaller.h>
  #include <cppunit/TestSuite.h>

  class clGridBase;
  class clSimManager;

  /**
   This class tests the Mortality behavior.  It writes out parameter files
   and uses them as input to perform setup; it then sets up the desired initial
   conditions, causes the behavior to run, then tests its output.  There will be
   one normal processing run and two error runs.
   */
  class clTestCompetitionMortality : public CppUnit::TestFixture
  {

  public:

  /**
   Tests normal processing mortality.  It will cause a  parameter file to
   be written and then passed to a clSimManager object.  This
   object will read it.  The Mortality behavior is run and seedlings counted.
  */
    void TestMortality();

  private:

    /**
     Writes a parameter file to direct testing using the first set of testing
     conditions.  This contains all tree information and disperse information.
     It also has a tree map so we'll be dealing with a known list of trees.

     @return Filename written.
    */
    char * WriteXMLFile1();

    /**
     Writes a bad parameter file: Passes a timestep >1 to this behavior.

     @return Filename written.
    */
    char * WriteXMLFile2();



  };
//---------------------------------------------------------------------------

#endif // TestMortality_H
