//---------------------------------------------------------------------------
// TestGermination
//---------------------------------------------------------------------------
#if !defined(TestGermination_H)
  #define TestGermination_H

  #include <cppunit/TestFixture.h>
  #include <cppunit/TestCaller.h>
  #include <cppunit/TestSuite.h>

  class clGridBase;
  class clSimManager;

  /**
   This class tests the germination behavior.  It writes out parameter files
   and uses them as input to perform setup; it then sets up the desired initial
   conditions, causes the behavior to run, then tests its output.  There will be
   one normal processing run and two error runs.
   */
  class clTestGermination : public CppUnit::TestFixture
  {

  public:

  /**
   Tests normal processing germination.  It will cause a  parameter file to
   be written and then passed to a clSimManager object.  This
   object will read it.  The germination behavior is run and seedlings counted.
  */
    void TestGermination();

  private:

  /**
  * Tests normal processing.
  * @param p_oSimManager Sim Manager object.
  */
  void TestGerminationNormalProcessing(clSimManager *p_oSimManager);

  /**
  * This tests the two error processing files.
  * @param p_oSimManager Sim Manager object.
  */
  void TestGerminationErrorProcessing(clSimManager *p_oSimManager);

  /** Verifies the seedling counts for TestGermination.
  * @param p_oSeedGrid Dispersed seeds grid.
  */
  void VerifyXMLFile1(clGridBase * p_oSeedGrid);

    /**
     Writes a parameter file to direct testing using the first set of testing
     conditions.  This contains all tree information and disperse information.
     It also has a tree map so we'll be dealing with a known list of trees.

     @return Filename written.
    */
    char * WriteXMLFile1();

    /**
     Writes a parameter file with a germination parameter less than 0.

     @return Filename written.
    */
    char * WriteXMLErrorFile1();

    /**
     Writes a parameter file with a germination parameter greater than 1.

     @return Filename written.
    */
    char * WriteXMLErrorFile2();

  };
//---------------------------------------------------------------------------

#endif // TestGermination_H
