//---------------------------------------------------------------------------
// TestSpatialDispersal
//---------------------------------------------------------------------------
#if !defined(TestSpatialDispersal_H)
  #define TestSpatialDispersal_H

  #include <cppunit/TestFixture.h>
  #include <cppunit/TestCaller.h>
  #include <cppunit/TestSuite.h>

class clGridBase;
class clSimManager;

/**
  This class tests the spatial dispersal behavior.  It writes out parameter files
  and uses them as input to perform setup; it then sets up the desired initial
  conditions, causes the behavior to run, then tests its output.
  <p>
  Two runs will be tested:  one in which the timestep length is 1 year and the
  dimensions of the seed grid are explicitly set to 2X4 m, and one in which the
  timestep length is 4 years and the dimensions of the seed grid are left to
  default.  The first parameter file is run for 2 timesteps to ensure that the
  seed grid is cleared between timesteps.
*/
class clTestSpatialDispersal : public CppUnit::TestFixture {

public:

/**
* Performs the total test of disperse by calling TestDispersal1 and
* TestDispersal2.
*/

  void TestSpatialDisperse();


/**
  Creates a test suite of all the test cases in this object.  I'm putting
  it here so it will be easier to see and add new cases to.

  @return The test suite.
*/

/*static CppUnit::Test *suite () {
 CppUnit::TestSuite *suite = new CppUnit::TestSuite ("TestSpatialDispersal");

  suite->addTest (new CppUnit::TestCaller <TestSpatialDispersal> ("TestDispersal1",
        &TestSpatialDispersal::TestDispersal1));
  suite->addTest (new CppUnit::TestCaller <TestSpatialDispersal> ("TestDispersal2",
        &TestSpatialDispersal::TestDispersal2));

  return suite;
}; */

private:

/**
  Tests spatial dispersal using the first set of conditions.  It will cause a
  parameter file to be written and then passed to a clSimManager object.  This
  object will read it.  The disperse behavior is run and the contents of the
  seed grid examined.
  @param p_oSimManager Sim manager object.
*/
void TestDispersal1(clSimManager *p_oSimManager);

/**
  Tests spatial dispersal using the second set of conditions.  It will cause a
  parameter file to be written and then passed to a clSimManager object.  This
  object will read it.  The disperse behavior is run and the contents of the
  seed grid examined.
  @param p_oSimManager Sim manager object.
*/
void TestDispersal2(clSimManager *p_oSimManager);


/**
* Verifies the numbers of seeds for timestep 1 during TestDispersal1.
*/
  void VerifyXMLFile1Timestep1(clGridBase *p_oSeedGrid);

  /**
  * Verifies the numbers of seeds for timestep 2 during TestDispersal1.  This
  * checks two things:  one, that the number of seeds got cleaned out during
  * timestep cleanup, and two, that the stump was removed.  (So the number
  * of seeds for one species will be slightly different.)
  */
  void VerifyXMLFile1Timestep2(clGridBase *p_oSeedGrid);


  /**
  * Verifies the numbers of seeds during TestDispersal2.
  */
    void VerifyXMLFile2(clGridBase *p_oSeedGrid);

  /**
    Writes a parameter file to direct testing using the first set of testing
    conditions.  This contains all tree information and disperse information.
    It also has a tree map so we'll be dealing with a known list of trees.

    @return Filename written.
  */
  char* WriteXMLFile1();

  /**
    Writes a parameter file to direct testing using the second set of testing
    conditions.  This contains all tree information and disperse information.
    It also has a tree map so we'll be dealing with a known list of trees.

    @return Filename written.
  */
  char* WriteXMLFile2();
};
//---------------------------------------------------------------------------

#endif // TestSpatialDispersal_H
