//---------------------------------------------------------------------------
// TestSubstrateDepSeedSurvival
//---------------------------------------------------------------------------
#if !defined(TestSubstrateDepSeedSurvival_H)
  #define TestSubstrateDepSeedSurvival_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* This class tests the clSubstrateDepSeedSurvival class.
*/
class clTestSubstrateDepSeedSurvival : public CppUnit::TestFixture
{

  public:

  /**
  * Rolls up all the tests into one function.
  */
  void TestSubstrateDepSeedSurvival();

  private:

  /**
  * Performs run 1 of normal processing.  WriteXMLFile1() does setup.  This
  * run has no gap status.  Grid cell size is default for all grids.  There are
  * seven species but the first is not used.  Non-spatial disperse is used but
  * given parameter values such that it will add no seeds.  Establishment will
  * turn our surviving seeds into seedlings.  We are interested in 4 grid
  * cells; for each of these, the substrate proportions are set in the
  * "Substrate" grid and 1000 seeds of each species are added to the "Dispersed
  * Seeds" grid.  Then the run progresses and the seedlings are counted.
  * @param p_oSimManager For running the sim.
  */
  void TestNormalProcessingRun1(clSimManager *p_oSimManager);

  /**
  * Performs run 2 of normal processing.  WriteXMLFile2() does setup.  This
  * run has gap status.  Grid cell size is default for all grids.  There are
  * seven species but the first is not used.  Spatial disperse is used but
  * given parameter values such that it will add no seeds.  Establishment will
  * turn our surviving seeds into seedlings.  We are interested in 4 grid
  * cells; for each of these, the substrate proportions are set in the
  * "Substrate" grid and 1000 seeds of each species are added to the "Dispersed
  * Seeds" grid.  Then the run progresses and the seedlings are counted.
  * @param p_oSimManager For running the sim.
  */
  void TestNormalProcessingRun2(clSimManager *p_oSimManager);

  /**
  * Performs run 3 of normal processing.  WriteXMLFile3() does setup.  This
  * run has no gap status.  Grid cell size is 16 X 16 m for "Dispersed Seeds"
  * and 8 X 8 m for "Substrate".  There are seven species but the first is not
  * used.  Non-spatial disperse is used but given parameter values such that it
  * will add no seeds.  Establishment will turn our surviving seeds into
  * seedlings.  We are interested in 4 grid cells in "Substrate" and the
  * corresponding single grid cell encompassing them in "Dispersed Seeds"; for
  * each of these, the substrate proportions are set in the "Substrate" grid
  * and 1000 seeds of each species are added to the "Dispersed Seeds" grid.
  * Then the run progresses and the seedlings are counted.
  * @param p_oSimManager For running the sim.
  */
  void TestNormalProcessingRun3(clSimManager *p_oSimManager);

  /**
  * Performs run 4 of normal processing.  WriteXMLFile4() does setup.  This
  * run has microtopography.  Grid cell size is default for all grids.  There
  * are seven species but the first is not used.  Non-spatial disperse is used
  * but given parameter values such that it will add no seeds.  Establishment
  * will turn our surviving seeds into seedlings.  We are interested in 4 grid
  * cells; for each of these, the substrate proportions are set in the
  * "Substrate" grid and 1000 seeds of each species are added to the "Dispersed
  * Seeds" grid.  Then the run progresses and the seedlings are counted.
  * @param p_oSimManager For running the sim.
  */
  void TestNormalProcessingRun4(clSimManager *p_oSimManager);

  /**
  * Performs error testing.  This feeds in the set of error parameter files
  * and verifies that the correct error is thrown for each.
  * @param p_oSimManager For running the sim.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Writes a parameter file to direct testing for NormalProcessingRun1.
  * @return Filename written.
  */
  char * WriteXMLFile1();

  /**
  * Writes a parameter file to direct testing for NormalProcessingRun2.
  * @return Filename written.
  */
  char * WriteXMLFile2();

  /**
  * Writes a parameter file to direct testing for NormalProcessingRun3.
  * @return Filename written.
  */
  char * WriteXMLFile3();

  /**
  * Writes a parameter file to direct testing for NormalProcessingRun4.
  * @return Filename written.
  */
  char * WriteXMLFile4();

  /**
  * Writes a parameter file with a substrate favorability not between 0 and 1.
  * @return Filename written.
  */
  char * WriteXMLErrorFile1();

  /**
  * Writes a parameter file where substrate isn't used.
  * @return Filename written.
  */
  char * WriteXMLErrorFile2();

  /**
  * Writes a parameter file where a disperse behavior isn't used.
  * @return Filename written.
  */
  char * WriteXMLErrorFile3();

  /**
  * Writes a parameter file where gap is used but gap disperse behavior isn't
  * used.
  * @return Filename written.
  */
  char * WriteXMLErrorFile4();

  /**
  * Writes common portions of the test parameter files (tree pop, plot, etc).
  * This ends with &lt;/allometry&gt;.
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);
};

//---------------------------------------------------------------------------
#endif // TestEstablishment
